@@ -21,7 +21,9 @@ from collections import namedtuple
 from tornado import gen
 from nbformat.v4 import new_notebook
 from .cortx_authenticator import CortxAuthenticator
-from .utils import (MultiPartUploadHelper,_get_key,_get_path, _get_full_path)
+# from .utils import (MultiPartUploadHelper,_get_key,_get_path, _get_full_path,_get_type,_get_format,_get_type_from_key)
+from .utils import *
+
 import json 
 
 import nbformat
@@ -154,16 +156,6 @@ class CortxJupyter(ContentsManager):
         )
 
 
-# def get_key(config, path):
-#     return config.prefix + path.lstrip('/')
-
-# def get_path(config, key):
-#     return '/' + key[len(config.prefix):]
-
-
-# def _get_full_path(key_or_path):
-#     return key_or_path.split('/')[-1]
-
 def _copy_sort_key(key):
     return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
 
@@ -171,31 +163,6 @@ def _copy_sort_key(key):
 def _delete_sort_key(key):
     return tuple(-1 * key_i for key_i in _copy_sort_key(key))
 
-@gen.coroutine
-def _type_from_path(config, path):
-    type = \
-        'notebook' if path.endswith(NB_TYPE) else \
-        'directory' if _is_root(path) or (yield _dir_exists(config, path)) else \
-        'file'
-    return type
-
-
-def _format_from_type_and_path(config, type, path):
-    type = \
-        'json' if type == 'notebook' else \
-        'json' if type == 'directory' else \
-        'text' if mimetypes.guess_type(path)[0] == 'text/plain' else \
-        'base64'
-    return type
-
-
-def _type_from_path_not_directory(path):
-    type = \
-        'notebook' if path.endswith(NB_TYPE) else \
-        'file'
-    return type
-
-
 @gen.coroutine
 def _dir_exists(config, path):
     return True if _is_root(path) else (yield _file_exists(config, path + FOLDER_SEPERATOR))
@@ -212,7 +179,7 @@ def _file_exists(config, path):
 
     @gen.coroutine
     def key_exists():
-        key = get_key(config, path)
+        key = _get_key(config, path)
         try:
             response = yield _head_object(config, config.bucket_name, key)
             
@@ -233,8 +200,8 @@ def _exists(config, path):
 
 @gen.coroutine
 def _get(config, path, content, type, format):
-    type_to_get = type if type is not None else (yield _type_from_path(config, path))
-    format_to_get = format if format is not None else _format_from_type_and_path(config, type_to_get, path)
+    type_to_get = type if type is not None else (yield _get_type(config, path))
+    format_to_get = format if format is not None else _get_format(config, type_to_get, path)
     return (yield GETTERS[(type_to_get, format_to_get)](config, path, content))
 
 
@@ -257,7 +224,7 @@ def _get_file_text(config, path, content):
 @gen.coroutine
 def _get_any(config, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
-    key = get_key(config, path)
+    key = _get_key(config, path)
     response = yield _get_object(config, config.bucket_name, key)
     file_bytes = response['Body'].read()
     last_modified_str = response['LastModified']
@@ -282,7 +249,7 @@ def _get_any(config, path, content, type, mimetype, format, decode):
 
 @gen.coroutine
 def _get_directory(config, path, content):
-    key = get_key(config, path)
+    key = _get_key(config, path)
     key_prefix = key if (key == '' or key[-1] == '/') else (key + '/')
     keys, directories = \
         (yield _list_immediate_child_keys_and_directories(config, key_prefix)) if content else \
@@ -309,7 +276,7 @@ def _get_directory(config, path, content):
             if directory not in all_keys
         ] + [
             {
-                'type': _type_from_path_not_directory(key),
+                'type': _get_type_from_key(key),
                 'name': _get_full_path(key),
                 'path': _get_path(config, key),
                 'last_modified': last_modified,
@@ -322,10 +289,10 @@ def _get_directory(config, path, content):
 
 @gen.coroutine
 def _save(config, model, path):
-    type_to_save = model['type'] if 'type' in model else (yield _type_from_path(config, path))
-    format_to_save = model['format'] if 'format' in model else _format_from_type_and_path(
-        config, type_to_save, path)
-    return (yield SAVERS[(type_to_save, format_to_save)](
+    save_type = model['type'] if 'type' in model else (yield _get_type(config, path))
+    save_format = model['format'] if 'format' in model else _get_format(
+        config, save_type, path)
+    return (yield SAVERS[(save_type, save_format)](
         config,
         model['chunk'] if 'chunk' in model else None,
         model['content'] if 'content' in model else None,
@@ -365,12 +332,11 @@ def _save_any(config, chunk, content_bytes, path, type, mimetype):
 
 @gen.coroutine
 def _save_chunk(config, chunk, content_bytes, path, type, mimetype):
-    # Chunks are 1-indexed
+
     if chunk == 1:
         config.multipart_uploads[path] = []
     config.multipart_uploads[path].append(content_bytes)
 
-    # -1 is the last chunk
     if chunk == -1:
         combined_bytes = b''.join(config.multipart_uploads[path])
         del config.multipart_uploads[path]
@@ -440,7 +406,7 @@ def _create_checkpoint(config, path):
 
 @gen.coroutine
 def _get_model_at_checkpoint(config, type, checkpoint_id, path):
-    format = _format_from_type_and_path(config, type, path)
+    format = _get_format(config, type, path)
     checkpoint_path = _checkpoint_path(path, checkpoint_id)
     return (yield GETTERS[(type, format)](config, checkpoint_path, True))
 
@@ -479,7 +445,7 @@ def _rename(config, old_path, new_path):
     if (yield _exists(config, new_path)):
         raise HTTPServerError(400, "Target already exists")
 
-    type = yield _type_from_path(config, old_path)
+    type = yield _get_type(config, old_path)
     old_key = _get_key(config, old_path)
     new_key = _get_key(config, new_path)
 
@@ -495,10 +461,6 @@ def _rename(config, old_path, new_path):
         for (key, _) in (yield _list_all_descendant_keys(config, old_key + '/'))
     ]
 
-    # We can't really do a transaction on S3, and not sure if we can trust that on any error
-    # from DELETE, that the DELETE hasn't happened: even checking if the file is still there
-    # isn't bulletproof due to eventual consistency. So we risk duplicate files over risking
-    # deleted files
     for (old_key, new_key) in object_key + sorted(renames, key=lambda k: _copy_sort_key(k[0])):
         yield _copy_key(config, old_key, new_key)
 
@@ -519,7 +481,7 @@ def _delete(config, path):
     if not path:
         raise HTTPServerError(400, "Can't delete root")
 
-    type = _type_from_path(config, path)
+    type = _get_type(config, path)
     root_key = _get_key(config, path)
 
     object_key = \
