@@ -39,4 +39,29 @@ def _get_path(config, key):
     return '/' + key[len(config.prefix):]
 
 def _get_full_path(key_or_path):
-    return key_or_path.split('/')[-1]
\ No newline at end of file
+    return key_or_path.split('/')[-1]
+
+
+@gen.coroutine
+def _get_type(config, path):
+    type = \
+        'notebook' if path.endswith(NB_TYPE) else \
+        'directory' if _is_root(path) or (yield _dir_exists(config, path)) else \
+        'file'
+    return type
+
+
+def _get_format(config, type, path):
+    type = \
+        'json' if type == 'notebook' else \
+        'json' if type == 'directory' else \
+        'text' if mimetypes.guess_type(path)[0] == 'text/plain' else \
+        'base64'
+    return type
+
+
+def _get_type_from_key(key):
+    type = \
+        'notebook' if key.endswith(NB_TYPE) else \
+        'file'
+    return type
\ No newline at end of file
